pub struct DirectedGraph { /* private fields */ }
Loopless directed graphs.

The possible relations between two vertices is described by the type Arc.

Implementations

source

impl DirectedGraph

source

pub fn new<I>(n: usize, arcs: I) -> Selfwhere I: IntoIterator<Item = (usize, usize)>,

Create a directed graph with n vertices and arcs in arcs.

Panics
  • If arcs contains vertices not in {0, ..., n-1}
  • If a loop (u, u) is provided
  • If some arc is provided twice
use flag_algebra::flags::OrientedGraph;

// Oriented path with 3 vertices `0 -> 1 -> 2`
let p3 = OrientedGraph::new(3, [(0, 1), (1, 2)]);
source

pub fn size(&self) -> usize

Number of vertices

source

pub fn out_nbrs(&self, v: usize) -> Vec<usize>

Out-neigborhood of v.

use flag_algebra::flags::OrientedGraph;
let p3 = OrientedGraph::new(3, [(0,1), (1,2)]);
assert_eq!(p3.out_nbrs(1), vec![2]);
source

pub fn in_nbrs(&self, v: usize) -> Vec<usize>

In-neigborhood of v.

use flag_algebra::flags::OrientedGraph;
let p3 = OrientedGraph::new(3, [(0, 1), (1, 2)]);
assert_eq!(p3.in_nbrs(1), vec![0]);
source

pub fn arc(&self, u: usize, v: usize) -> Arc

Oriented relation between u to v.

use flag_algebra::flags::{DirectedGraph, Arc};
let g = DirectedGraph::new(3, [(0, 1), (1, 2), (2, 1)]);
assert_eq!(g.arc(0, 1), Arc::Edge);
assert_eq!(g.arc(1, 0), Arc::BackEdge);
assert_eq!(g.arc(0, 2), Arc::None);
assert_eq!(g.arc(1, 2), Arc::Reciprocal);