[][src]Function flag_algebra::init_default_log

pub fn init_default_log()

Initialize the logs to be outputted to the console.

In order to be recorded, the logs need to be initialized via this function or any initializer of the simplelog library