[][src]Trait flag_algebra::iterators::StreamingIterator

pub trait StreamingIterator<A> where
    A: ?Sized
{ fn next(&mut self) -> Option<&A>; fn count(self) -> usize
    where
        Self: Sized
, { ... } }

Interface for streaming iterators.

Similarly as in the streaming-iterator crate, the elements yielded by the iterator are borrowed by the iterator. A loop on such an iterator iter is written as follows.

This example is not tested
while let Some(item) = iter.next() {
    ...
}

Required methods

fn next(&mut self) -> Option<&A>

Return the next value of the iterator.

Loading content...

Provided methods

fn count(self) -> usize where
    Self: Sized

Consume the iterator and return the number of elements yielded.

Loading content...

Implementors

impl StreamingIterator<[usize]> for Choose[src]

impl StreamingIterator<[usize]> for Functions[src]

impl StreamingIterator<[usize]> for Injection[src]

impl StreamingIterator<[usize]> for Subsets[src]

Loading content...