[−][src]Module flag_algebra::operator
Computing and stocking operators of the flag algebra.
Structs
| Basis | The set of flags of size size and type t .get() returns an ordered vector containing all corresponding flags |
| MulAndUnlabeling | |
| SplitCount | Operator used for flag multiplication .get() returns a vector of matrices M where M[i][j, k] is the number of ways to split i into j and k |
| SubflagCount | .get() gives a matrix M where M[i,j] is the number of copies of i in j |
| Type | Type (or root) of a flag. It is identified by its size and its id in the list of flags of that size. |
| Unlabeling | Let F be the flag indexed by id on basis basis this represents the unlabeling opearation that sends the type fully_typed(F) to the flag F |
| UnlabelingCount | |
| UnlabelingFlag |
Traits
| Savable | A trait for flag operators that can be saved in a file once computed for the first time. |
Functions
| flag | |
| flag_typed |