Struct flag_algebra::operator::Type
source · pub struct Type<F: Flag> {
pub size: usize,
pub id: usize,
/* private fields */
}Expand description
Type (or root) of a flag. It is identified by its size and its id in the list of flags of that size.
Fields
size: usizeSize of the type.
id: usizeIndex of the type in the list of unlabeled flags of this size.
Implementations
sourceimpl<F: Flag> Type<F>
impl<F: Flag> Type<F>
sourcepub fn from_flag<G>(g: &G) -> Selfwhere
F: Flag,
G: Into<F> + Clone,
pub fn from_flag<G>(g: &G) -> Selfwhere F: Flag, G: Into<F> + Clone,
Create the type corresponding to g
sourcepub fn types_with_size(size: usize) -> impl Iterator<Item = Self>where
F: Flag,
pub fn types_with_size(size: usize) -> impl Iterator<Item = Self>where F: Flag,
Iterate on all types of a given size.
sourcepub fn print_concise(self) -> String
pub fn print_concise(self) -> String
Print the type identifier in a short way.