[−][src]Struct flag_algebra::operator::Unlabeling
Let F be the flag indexed by id on basis basis
this represents the unlabeling opearation that
sends the type fully_typed(F) to the flag F
Fields
flag: usizebasis: Basis<F>Implementations
impl<F> Unlabeling<F>[src]
pub fn new(basis: Basis<F>, flag: usize) -> Self[src]
pub fn total(t: Type) -> Self[src]
pub fn input_type(&self) -> Type where
F: Flag, [src]
F: Flag,
pub fn output_type(&self) -> Type[src]
pub fn eta(&self) -> Vec<usize> where
F: Flag, [src]
F: Flag,
Return the eta function of Razborov corresponding to the untyping operator.