Struct flag_algebra::sdp::Problem

source ·
pub struct Problem<N, F: Flag> {
    pub ineqs: Vec<Ineq<N, F>>,
    pub cs: Vec<MulAndUnlabel<F>>,
    pub obj: QFlag<N, F>,
}
The optimisation problems over flags are translated into a sdp problem in the sdpa format.

Shape of the matrices:

For each i in ineqs (where i is itself a vector of inequalities): A diagonal block of size i.len()

For each cs: A block with the size od cs.input_matrix An optimization problem expressed in flags algebra.

Fields

ineqs: Vec<Ineq<N, F>>

Set of contraint inequalities.

cs: Vec<MulAndUnlabel<F>>

Set of Cauchy-Schwarz inequlities to be used.

obj: QFlag<N, F>

Vector to be optimized.

Implementations

source

impl<N, F: Flag> Problem<N, F>

source

pub fn minimize(obj: QFlag<N, F>) -> Selfwhere N: Display + Num + FromPrimitive + Clone + Neg<Output = N>,

Create a minimization problem with the argument as objective function.

source

pub fn check(&self)

Panic if the size of the basis involved are inconsistent.

source

impl<N, F> Problem<N, F>where N: Display + Zero + Copy + PartialEq + Neg<Output = N>, F: Flag,

source

pub fn write_sdpa(&self, filename: &str) -> Result<()>

Write the semi-definite program in the file filename in the sdpa format.

source

pub fn no_scale(self) -> Selfwhere N: DivAssign + ScalarOperand + FromPrimitive,

Rescale the objective according to its scale field. If this method is not used, the output of the sdp solver may need to be rescaled.

source

pub fn solve_csdp(&self, filename: &str) -> Result<f64, Error>

Solve the sdp using the CSDP solver.

source

pub fn run_csdp( &self, name: &str, initial_solution: Option<&str>, minimize_certificate: bool ) -> Result<f64, Error>