Struct flag_algebra::Ineq
source · pub struct Ineq<N, F: Flag> { /* private fields */ }Expand description
A set of bounds on elements of a flag algebra.
This correpond to a set of inequalities constructed in a similar way.
Implementations
sourceimpl<N, F> Ineq<N, F>where
N: Clone + Num,
F: Flag,
impl<N, F> Ineq<N, F>where N: Clone + Num, F: Flag,
sourceimpl<N, F> Ineq<N, F>where
N: Num + Clone + Send + Sync + Default + FromPrimitive + AddAssign + Sum + MulAcc,
F: Flag,
impl<N, F> Ineq<N, F>where N: Num + Clone + Send + Sync + Default + FromPrimitive + AddAssign + Sum + MulAcc, F: Flag,
sourcepub fn multiply_by_all(self, outbasis: Basis<F>) -> Selfwhere
N: Neg<Output = N>,
pub fn multiply_by_all(self, outbasis: Basis<F>) -> Selfwhere N: Neg<Output = N>,
If self is “f ≥ x”, return the set of inequalities “f*g ≥ x.g”,
where g is chosen such that f*g is a vector of outbasis.
sourcepub fn multiply_and_unlabel(self, outbasis: Basis<F>) -> Selfwhere
N: Neg<Output = N>,
pub fn multiply_and_unlabel(self, outbasis: Basis<F>) -> Selfwhere N: Neg<Output = N>,
If self is “f ≥ x”, return the set of inequalities “〚f*g〛 ≥ x.〚g〛”,
where g is chosen such that 〚f*g〛 is a vector of outbasis.