[][src]Struct flag_algebra::IneqData

pub struct IneqData<N> {
    pub flag: Array1<N>,
    pub bound: N,
}

Contains the vector and the bound of one inequality in a flag algebra. This inequality has the form self.flag ≥ self.bound. Expression recording how the left sides where constructed.

Fields

flag: Array1<N>

Vector of the left side in the corresponding flag basis.

bound: N

Number on the right side of the inequality.