[][src]Struct flag_algebra::IneqMeta

pub struct IneqMeta<N, F> {
    pub basis: Basis<F>,
    pub flag_expr: Expr<N, F>,
    pub bound_expr: Expr<N, F>,
    pub equality: bool,
    // some fields omitted
}

Contains informations about a set of inequalities of a flag algebra.

Fields

basis: Basis<F>

Basis in which the inequality is expressed. This correspond to the type and size of the flags.

flag_expr: Expr<N, F>

Expression recording how the left sides of the inequalities where constructed.

bound_expr: Expr<N, F>

Expression recording how the right sides where constructed.

equality: bool

True if the inequality is an equality