Struct flag_algebra::QFlag
source · pub struct QFlag<N, F: Flag> {
pub basis: Basis<F>,
pub data: Array1<N>,
pub scale: u64,
pub expr: Expr<N, F>,
}Expand description
An element of a flag algebra.
Fields
basis: Basis<F>Basis of the space where the element lives. This corresponds to the size and type of the flags.
data: Array1<N>The vector of the element in the corresponding basis is (1/self.scale).self.data.
scale: u64Scaling factor of the vector.
expr: Expr<N, F>Expression recording how the vector was computed.
Implementations
sourceimpl<N, F: Flag> QFlag<N, F>
impl<N, F: Flag> QFlag<N, F>
sourcepub fn expand(&self, outbasis: Basis<F>) -> Selfwhere
N: Num + Clone + FromPrimitive,
pub fn expand(&self, outbasis: Basis<F>) -> Selfwhere N: Num + Clone + FromPrimitive,
Projection to a basis of larger flag.
sourcepub fn untype(&self) -> Selfwhere
N: Num + Clone + FromPrimitive,
pub fn untype(&self) -> Selfwhere N: Num + Clone + FromPrimitive,
Unlabeling operator 〚.〛 to the flag algebra of completly unlabeled flags.
sourcepub fn with_expr(self, expr: Expr<N, F>) -> Self
pub fn with_expr(self, expr: Expr<N, F>) -> Self
Return the same element with modified pretty-print expression
sourcepub fn no_scale(self) -> Selfwhere
N: FromPrimitive + DivAssign<N> + ScalarOperand,
pub fn no_scale(self) -> Selfwhere N: FromPrimitive + DivAssign<N> + ScalarOperand,
Divide the elements of the vector by the scale and set the scale to 1
pub fn map<G, M>(&self, g: G) -> QFlag<M, F>where G: Fn(&N) -> M,