pub struct SubClass<F, A> {
pub content: F,
// some fields omitted
}A wrapper type for flags from a sub-class of flags.
A name for this type of flags. For instance "Graphe". This name is used for naming the associated data subdirectory. Read more
Return the list of flags of size self.size() + 1 that contain self as an induced subflag. Read more
Returns the subflag induced by the vertices in the slice set.
Returns the set of all flags of size n. Read more
Return the list of flags of size self.size() + 1 that contain self as an induced subflag reduced modulo isomorphism. Read more
Return the list of flags of size n reduced modulo isomorphism.
Return the list of flags of g_vec that can be rooted on the flag type_flag. Each different way to root this flag give a different flag in the result. Read more
Return the list of flag of size size rooted on type_flag reduced modulo (typed) isomorphism. Read more
Reorder self so that the eta.len() first vertices are the values of eta in the corresonding order. Read more
This method tests for self and other values to be equal, and is used by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
This method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self | 1.21.0 [src] |
Compares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self | 1.21.0 [src] |
Compares and returns the minimum of two values. Read more
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Formats the value using the given formatter. Read more
Serialize this value into the given Serde serializer. Read more
Deserialize this value from the given Serde deserializer. Read more
Return lists of vertices that are invariant isomorphism. Read more
Returns the result of the action of a permuation perm on the object. Read more
Can return a coloring that is invariant by isomorphism. Read more
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
Converts the given value to a String. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Mutably borrows from an owned value. Read more
impl<SS, SP> SupersetOf for SP where SS: SubsetOf<SP>, | |
The inverse inclusion map: attempts to construct self from the equivalent element of its superset. Read more
Checks if self is actually part of its subset T (and can be converted to it).
Use with care! Same as self.to_subset but without any property checks. Always succeeds.
The inclusion map: converts self to the equivalent element of its superset.