Enum flag_algebra::flags::Arc
source · pub enum Arc {
None,
Edge,
BackEdge,
Reciprocal,
}Expand description
The arc between two nodes of a directed graphs.
Variants
None
No arc.
Edge
Arc from the first to the second vertex considered.
BackEdge
Arc from the second to the first vertex considered.
Reciprocal
Arcs in both directions