[][src]Enum flag_algebra::flags::Arc

pub enum Arc {
    None,
    Edge,
    BackEdge,
}

The arc between two nodes of a directed graphs.

Variants

None

No arc.

Edge

Arc from the first to the second vertex considered.

BackEdge

Arc from the second to the first vertex considered.