[−][src]Struct flag_algebra::flags::Digraph
Directed graphs.
Fields
edge: AntiSym<Arc>Flat matrix of arcs.
Methods
impl Digraph[src]
pub fn size(&self) -> usize[src]
Number of vertices
pub fn out_nbrs(&self, v: usize) -> Vec<usize>[src]
Out-neigborhood of v in self.
pub fn in_nbrs(&self, v: usize) -> Vec<usize>[src]
In-neigborhood of v in self.
pub fn new(n: usize, arcs: &[(usize, usize)]) -> Self[src]
Directed graph with n vertices and arcs arcs.
pub fn empty(n: usize) -> Self[src]
Directed graph with n vertices and no edge.
pub fn add_sink(&self) -> Self[src]
Directed graph obtained from self by adding a vertex and every edge
from the rest of the graph to that vertex.