[−][src]Struct flag_algebra::flags::Graph
An undirected graph.
Implementations
impl Graph[src]
pub fn size(&self) -> usize[src]
Return the number of vertices in the graph
pub fn nbrs(&self, v: usize) -> Vec<usize>[src]
Return the vector of vertices adjacent to v.
pub fn new(n: usize, edge: &[(usize, usize)]) -> Self[src]
Create a graph on n vertices with edge set edge.
The vertices of this graph are 0,...,n-1.
pub fn empty(n: usize) -> Self[src]
Create the graph on n vertices with no edge.
pub fn edge(&self, u: usize, v: usize) -> bool[src]
Returns true id uv is an edge.
pub fn edges(&self) -> EdgeIterator<'_>ⓘNotable traits for EdgeIterator<'a>
impl<'a> Iterator for EdgeIterator<'a> type Item = (usize, usize);[src]
Notable traits for EdgeIterator<'a>
impl<'a> Iterator for EdgeIterator<'a> type Item = (usize, usize);pub fn connected(&self) -> bool[src]
Returns true if the graph is connected.
impl Graph[src]
pub fn petersen() -> Self[src]
pub fn clique(n: usize) -> Self[src]
pub fn cycle(n: usize) -> Self[src]