[][src]Struct flag_algebra::flags::Graph

pub struct Graph { /* fields omitted */ }

An undirected graph.

Methods

impl Graph
[src]

pub fn nbrs(&self, v: usize) -> Vec<usize>
[src]

Return the vector of vertices adjacent to v.

pub fn new(n: usize, edge: &[(usize, usize)]) -> Graph
[src]

Create a graph on n vertices with edge set edge. The vertices of this graph are 0,...,n-1.

pub fn empty(n: usize) -> Graph
[src]

Create the graph on n vertices with no edge.

pub fn edge(&self, u: usize, v: usize) -> bool
[src]

Returns true id uv is an edge.

pub fn connected(&self) -> bool
[src]

Returns true if the graph is connected.

impl Graph
[src]

pub fn petersen() -> Self
[src]

pub fn clique(n: usize) -> Self
[src]

pub fn cycle(n: usize) -> Self
[src]