[][src]Struct flag_algebra::iterators::Split

pub struct Split { /* fields omitted */ }

Iterator on the partitions of [n] into two sets of respective size k and n-k.

Methods

impl Split
[src]

pub fn new(n: usize, k: usize) -> Self
[src]

Create an iterator on partitions of [n] into two sets of respective size k and n-k.

pub fn with_fixed_part(n: usize, k: usize, fixed: usize) -> Self
[src]

Create an iterator on partitions of [n] into two sets of respective size k and n-k+fixed that both contain [fixed].

pub fn next(&mut self) -> Option<(&[usize], &[usize])>
[src]

Yield next element of the iterator.

Because of the type of this function, Split does not implement the trait StreamingIterator.