[−][src]Trait flag_algebra::iterators::StreamingIterator
Interface for streaming iterators.
Similarly as in the streaming-iterator crate, the elements yielded by the iterator
are borrowed by the iterator.
A loop on such an iterator iter is written as follows.
ⓘThis example is not tested
while let Some(item) = iter.next() { ... }
Required methods
Loading content...Provided methods
fn count(self) -> usize where
Self: Sized,
Self: Sized,
Consume the iterator and return the number of elements yielded.
Implementors
impl StreamingIterator<[usize]> for Choose[src]
impl StreamingIterator<[usize]> for Chooseimpl StreamingIterator<[usize]> for Functions[src]
impl StreamingIterator<[usize]> for Functionsimpl StreamingIterator<[usize]> for Injection[src]
impl StreamingIterator<[usize]> for Injectionimpl StreamingIterator<[usize]> for Subsets[src]
impl StreamingIterator<[usize]> for Subsets