[−][src]Struct flag_algebra::operator::Basis
The set of flags of size size and type t .get() returns an ordered vector containing all corresponding flags
Fields
size: usizeNumber of vertices of the flags of the basis.
t: TypeType of the flags of the basis.
Methods
impl<F: Flag> Basis<F>[src]
pub fn make(size: usize, t: Type) -> Self[src]
Constructor for a basis.
pub fn new(size: usize) -> Self[src]
Basis of flag with size vertices and without type.
pub fn with_size(&self, size: usize) -> Self[src]
Basis of flag with size vertices and same type as self.
pub fn with_type(&self, t: Type) -> Self[src]
Basis of flag with same size as self and type t.
pub fn without_type(&self) -> Self[src]
Basis of flag with same size as self without type t.
pub fn print_concise(&self) -> String[src]
Print the basis information in a short way
impl<F> Basis<F> where
F: Flag, [src]
F: Flag,
Constructing quantum graphs on a basis
pub fn zero<N>(self) -> QFlag<N, F> where
N: Num + Clone, [src]
N: Num + Clone,
pub fn one<N>(self) -> QFlag<N, F> where
N: Num + Clone, [src]
N: Num + Clone,
pub fn random<N>(self) -> QFlag<N, F> where
N: From<i16>, [src]
N: From<i16>,
pub fn flag_from_id<N>(self, id: usize) -> QFlag<N, F> where
N: Num + Clone, [src]
N: Num + Clone,
pub fn flag_from_id_with_base_size<N>(
self,
id: usize,
size: usize
) -> QFlag<N, F> where
N: Num + Clone, [src]
self,
id: usize,
size: usize
) -> QFlag<N, F> where
N: Num + Clone,
pub fn flag<N>(self, f: &F) -> QFlag<N, F> where
N: Num + Clone, [src]
N: Num + Clone,
pub fn from_vec<N>(self, vec: Vec<N>) -> QFlag<N, F>[src]
pub fn from_coeff<M, N, P>(&self, f: P) -> QFlag<N, F> where
M: Into<N>,
P: FnMut(&F, usize) -> M, [src]
M: Into<N>,
P: FnMut(&F, usize) -> M,
pub fn from_indicator<N, P>(&self, f: P) -> QFlag<N, F> where
N: One + Zero,
P: FnMut(&F, usize) -> bool, [src]
N: One + Zero,
P: FnMut(&F, usize) -> bool,
pub fn all_cs(&self) -> Vec<MulAndUnlabeling<F>>[src]