pub struct Basis<F> {
pub size: usize,
pub t: Type,
// some fields omitted
}The set of flags of size size and type t
.get() returns an ordered vector containing all corresponding flags
Number of vertices of the flags of the basis.
Type of the flags of the basis.
Basis of flag with size vertices and without type.
Basis of flag with size vertices and same type as self.
Basis of flag with same size as self and type t.
Basis of flag with same size as self without type t.
Constructing quantum graphs on a basis
Name of the file where the operator can be saved.
Path to the corresponding file.
(Re)create the object, save it in the corresponding file and return it.
Load the object if the file exists and is valid.
Function to automatically load the object if the file exists and is valid, or create and save it otherwise. Read more
This method tests for self and other values to be equal, and is used by ==. Read more
This method tests for !=.
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Formats the value using the given formatter. Read more
Feeds this value into the given [Hasher]. Read more
Feeds a slice of this type into the given [Hasher]. Read more
The resulting type after applying the * operator.
Performs the * operation.
The resulting type after applying the / operator.
Performs the / operation.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
Converts the given value to a String. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static
impl<SS, SP> SupersetOf for SP where SS: SubsetOf<SP>, | |
The inverse inclusion map: attempts to construct self from the equivalent element of its superset. Read more
Checks if self is actually part of its subset T (and can be converted to it).
Use with care! Same as self.to_subset but without any property checks. Always succeeds.
The inclusion map: converts self to the equivalent element of its superset.