[−][src]Struct flag_algebra::operator::Type
Type (or root) of a flag. It is identified by its size and its id in the list of flags of that size.
Fields
size: usizeSize of the type.
id: usizeIndex of the type in the list of unlabeled flags of this size.
Methods
impl Type[src]
pub fn new(size: usize, id: usize) -> Self[src]
Constructor for the type.
pub fn empty() -> Self[src]
Create a type of size 0.
pub fn is_empty(&self) -> bool[src]
Return wether the input has size zero
pub fn to_string(&self) -> String[src]
Write string that identify the type.
pub fn from_flag<F: Flag>(g: &F) -> Self[src]
pub fn print_concise(&self) -> String[src]
Print the basis information in a short way