[][src]Struct flag_algebra::operator::Type

pub struct Type {
    pub size: usize,
    pub id: usize,
}

Type (or root) of a flag. It is identified by its size and its id in the list of flags of that size.

Fields

size: usize

Size of the type.

id: usize

Index of the type in the list of unlabeled flags of this size.

Methods

impl Type
[src]

pub fn new(size: usize, id: usize) -> Self
[src]

Constructor for the type.

pub fn empty() -> Self
[src]

Create a type of size 0.

pub fn to_string(&self) -> String
[src]

Write string that identify the type.