[][src]Struct flag_algebra::operator::Unlabeling

pub struct Unlabeling<F> { /* fields omitted */ }

Let F be the flag indexed by id on basis basis this represents the unlabeling opearation that sends the type fully_typed(F) to the flag F

Methods

impl<F: Flag> Unlabeling<F>
[src]

pub fn new(basis: Basis<F>, flag: usize) -> Self
[src]

pub fn total(t: Type) -> Self
[src]

pub fn input_type(&self) -> Type
[src]

pub fn output_type(&self) -> Type
[src]

pub fn eta(&self) -> Vec<usize>
[src]