[−][src]Struct flag_algebra::sdp::Problem
The optimisation problems over flags are translated into a sdp problem in the sdpa format.
Shape of the matrices:
For each i in ineqs (where i is itself a vector of inequalities): A diagonal block of size i.len()
For each cs: A block with the size od cs.input_matrix An optimization problem expressed in flags algebra.
Fields
ineqs: Vec<Ineq<N, F>>Set of contraint inequalities.
cs: Vec<MulAndUnlabeling<F>>Set of Cauchy-Schwarz inequlities to be used.
obj: QFlag<N, F>Vector to be optimized.
Methods
impl<N, F> Problem<N, F> where
N: Display + Zero + Copy + PartialEq,
F: Flag, [src]
N: Display + Zero + Copy + PartialEq,
F: Flag,
pub fn check(&self)[src]
Panic if the size of the basis involved are inconsistent.
pub fn write_sdpa(&self, filename: &str) -> Result<()>[src]
Write the semi-definite program in the file filename in the sdpa format.