[][src]Struct flag_algebra::sdp::Problem

pub struct Problem<N, F> {
    pub ineqs: Vec<Ineq<N, F>>,
    pub cs: Vec<MulAndUnlabeling<F>>,
    pub obj: QFlag<N, F>,
}

An optimization problem expressed in flags algebra.

Fields

ineqs: Vec<Ineq<N, F>>

Set of contraint inequalities.

cs: Vec<MulAndUnlabeling<F>>

Set of Cauchy-Schwarz inequlities to be used.

obj: QFlag<N, F>

Vector to be optimized.

Methods

impl<N, F> Problem<N, F> where
    N: Display + Zero + Copy + PartialEq,
    F: Flag
[src]

pub fn check(&self)
[src]

Panic if the size of the basis involved are inconsistent.

pub fn write_sdpa(&self, filename: &str) -> Result<()>
[src]

Write the semi-definite program in the file filename in the sdpa format.