[−][src]Struct flag_algebra::sdp::ProblemView
A reference to a Problem filtered by a Selector.
Fields
obj: &'a QFlag<N, F>ineqs: Select<'a, Vec<Ineq<N, F>>, Vec<Vec<usize>>>cs: Select<'a, Vec<MulAndUnlabel<F>>, Vec<ArrayVec<[CSMode; 2]>>>cs_subspace: Vec<(usize, &'a CsMat<f64>)>Implementations
impl<'a, N, F> ProblemView<'a, N, F> where
N: Display + Neg<Output = N> + Zero + Copy + PartialEq,
F: Flag, [src]
N: Display + Neg<Output = N> + Zero + Copy + PartialEq,
F: Flag,
pub fn write_sdpa(&self, filename: &str) -> Result<()>[src]
Write the semi-definite program in the file filename in the sdpa format.