[−][src]Struct flag_algebra::Ineq
A set of bounds on elements of a flag algebra.
This correpond to a set of inequalities constructed in a similar way.
Fields
meta: IneqMeta<F>Common information about the set of inequalities.
data: Vec<IneqData<N>>List of data of the inequalities in the set.
Methods
impl<N, F> Ineq<N, F> where
N: Num + Neg<Output = N> + Clone,
F: Flag + Clone, [src]
impl<N, F> Ineq<N, F> where
N: Num + Neg<Output = N> + Clone,
F: Flag + Clone, pub fn opposite(self) -> Self | [src] |
If self is "f ≥ x", returns "f ≤ x".
pub fn equality(self) -> Self | [src] |
If self is "f ≥ x", returns "f = x".
impl<N, F> Ineq<N, F> where
N: Num + Copy + Default + AddAssign + NumCast + ScalarOperand,
F: Flag + Clone, [src]
impl<N, F> Ineq<N, F> where
N: Num + Copy + Default + AddAssign + NumCast + ScalarOperand,
F: Flag + Clone, impl<N, F> Ineq<N, F> where
N: Num + Copy + Default + AddAssign + SubAssign + ScalarOperand + NumCast,
F: Flag + Clone, [src]
impl<N, F> Ineq<N, F> where
N: Num + Copy + Default + AddAssign + SubAssign + ScalarOperand + NumCast,
F: Flag + Clone, pub fn multiply_by_qflag(&self, g: &QFlag<N, F>) -> Self | [src] |
If self is "f ≥ x", return the inequality "f*g ≥ x.g".
pub fn multiply_by_all(self, outbasis: Basis<F>) -> Self | [src] |
If self is "f ≥ x", return the set of inequalities "f*g ≥ x.g",
where g is chosen such that f*g is a vector of outbasis.
pub fn multiply_and_unlabel(self, outbasis: Basis<F>) -> Self | [src] |
If self is "f ≥ x", return the set of inequalities "〚f*g〛 ≥ x.〚g〛",
where g is chosen such that 〚f*g〛 is a vector of outbasis.