[−][src]Struct flag_algebra::IneqMeta
Contains informations about a set of inequalities of a flag algebra.
Fields
basis: Basis<F>Basis in which the inequality is expressed. This correspond to the type and size of the flags.
flag_expr: Expr<N, F>Expression recording how the left sides of the inequalities where constructed.
bound_expr: Expr<N, F>Expression recording how the right sides where constructed.
equality: boolTrue if the inequality is an equality