[][src]Struct flag_algebra::QFlag

pub struct QFlag<N, F> {
    pub basis: Basis<F>,
    pub data: Array1<N>,
    pub scale: u64,
    pub expr: Expr<N, F>,
}

An element of a flag algebra.

Fields

basis: Basis<F>

Basis of the space where the element lives. This corresponds to the size and type of the flags.

data: Array1<N>

The vector of the element in the corresponding basis is (1/self.scale).self.data.

scale: u64

Scaling factor of the vector.

expr: Expr<N, F>

Expression recording how the vector was computed.

Implementations

impl<N, F> QFlag<N, F> where
    N: Num + Clone + FromPrimitive,
    F: Flag
[src]

pub fn expand(&self, outbasis: Basis<F>) -> Self[src]

Projection to a basis of larger flag.

pub fn untype(&self) -> Self[src]

Unlabeling operator 〚.〛 to the flag algebra of completly unlabeled flags.

impl<N, F> QFlag<N, F>[src]

pub fn with_expr(self, expr: Expr<N, F>) -> Self[src]

Return the same element with modified pretty-print expression

pub fn named(self, name: String) -> Self[src]

Return the same element with modified pretty-print expression

pub fn no_scale(self) -> Self where
    N: FromPrimitive + DivAssign<N> + ScalarOperand
[src]

pub fn map<G, M>(&self, g: G) -> QFlag<M, F> where
    G: Fn(&N) -> M, 
[src]

impl<N, F> QFlag<N, F> where
    N: Num + FromPrimitive + Clone + Display,
    F: Flag
[src]

pub fn at_least(&self, x: N) -> Ineq<N, F>[src]

Return the inequality "selfx".

pub fn at_most(&self, x: N) -> Ineq<N, F> where
    N: Clone + Neg<Output = N>, 
[src]

Return the inequality "selfx".

pub fn non_negative(&self) -> Ineq<N, F> where
    N: Num
[src]

Return the inequality "self0".

pub fn equal(self, n: N) -> Ineq<N, F> where
    N: Clone + Neg<Output = N>, 
[src]

Return the equality "self = n".