[−][src]Struct flag_algebra::QFlag
An element of a flag algebra.
Fields
basis: Basis<F>Basis of the space where the element lives. This corresponds to the size and type of the flags.
data: Array1<N>The vector of the element in the corresponding basis is (1/self.scale).self.data.
scale: u64Scaling factor of the vector.
expr: Expr<N, F>Expression recording how the vector was computed.
Implementations
impl<N, F> QFlag<N, F> where
N: Num + Clone + FromPrimitive,
F: Flag, [src]
N: Num + Clone + FromPrimitive,
F: Flag,
pub fn expand(&self, outbasis: Basis<F>) -> Self[src]
Projection to a basis of larger flag.
pub fn untype(&self) -> Self[src]
Unlabeling operator 〚.〛 to the flag algebra of completly unlabeled flags.
impl<N, F> QFlag<N, F>[src]
pub fn with_expr(self, expr: Expr<N, F>) -> Self[src]
Return the same element with modified pretty-print expression
pub fn named(self, name: String) -> Self[src]
Return the same element with modified pretty-print expression
pub fn no_scale(self) -> Self where
N: FromPrimitive + DivAssign<N> + ScalarOperand, [src]
N: FromPrimitive + DivAssign<N> + ScalarOperand,
pub fn map<G, M>(&self, g: G) -> QFlag<M, F> where
G: Fn(&N) -> M, [src]
G: Fn(&N) -> M,
impl<N, F> QFlag<N, F> where
N: Num + FromPrimitive + Clone + Display,
F: Flag, [src]
N: Num + FromPrimitive + Clone + Display,
F: Flag,
pub fn at_least(&self, x: N) -> Ineq<N, F>[src]
Return the inequality "self ≥ x".
pub fn at_most(&self, x: N) -> Ineq<N, F> where
N: Clone + Neg<Output = N>, [src]
N: Clone + Neg<Output = N>,
Return the inequality "self ≤ x".
pub fn non_negative(&self) -> Ineq<N, F> where
N: Num, [src]
N: Num,
Return the inequality "self ≥ 0".
pub fn equal(self, n: N) -> Ineq<N, F> where
N: Clone + Neg<Output = N>, [src]
N: Clone + Neg<Output = N>,
Return the equality "self = n".