[−][src]Struct flag_algebra::QFlag
An element of a flag algebra.
Fields
basis: Basis<F>Basis of the space where the element lives. This corresponds to the size and type of the flags.
data: Array1<N>The vector of the element in the corresponding basis is (1/self.scale).self.data.
scale: u64Scaling factor of the vector.
expr: ExprExpression recording how the vector was computed.
Methods
impl<N, F> QFlag<N, F> where
N: Copy + Num + Default + NumCast + AddAssign,
F: Flag, [src]
impl<N, F> QFlag<N, F> where
N: Copy + Num + Default + NumCast + AddAssign,
F: Flag, pub fn expand(&self, outbasis: Basis<F>) -> Self | [src] |
Projection to a basis of larger flag.
pub fn untype(&self) -> Self | [src] |
Unlabeling operator 〚.〛 to the flag algebra of completly unlabeled flags.
impl<N, F> QFlag<N, F> where
N: Num + NumCast + Display,
F: Flag, [src]
impl<N, F> QFlag<N, F> where
N: Num + NumCast + Display,
F: Flag, pub fn at_least(self, x: N) -> Ineq<N, F> | [src] |
Return the inequality "self ≥ n".
pub fn at_most(self, n: N) -> Ineq<N, F> where | [src] |
Return the inequality "self ≤ n".
pub fn non_negative(self) -> Ineq<N, F> where | [src] |
Return the inequality "self ≥ 0".